@@ -7,6 +7,8 @@ from data.models.models import Calibration, Hardware, Accessory, Channel, Hardwa
     ModProbe, PiPico, VEML7700, HardwareChannelTypes, Hub, Category, AccessoryType, SPIIo, SerialIo, PwmIo, I2cIo, \
     DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, HardwareIO
 
+from OpenHubAPI.data.models.models import PMSA0031
+
 
 class HubForm(forms.ModelForm):
 
@@ -139,7 +141,7 @@ class HardwarePMSA0031Form(HardwareForm):
         super(HardwarePMSA0031Form, self).__init__(*args, **kwargs)
 
     class Meta:
-        model = VEML7700
+        model = PMSA0031
         fields = ("__all__")
 
 class AccessoryForm(forms.ModelForm):
@@ -398,8 +400,9 @@ MCP3008 = 'MCP3008'
 ModProbe = 'ModProbe'
 PiPico = 'PiPico'
 VEML7700 = 'VEML7700'
+PMSA0031 = 'PMSA0031'
 CHOICES = (('DHT22', 'DHT22'), ('MCP3008', 'MCP3008'), ('ModProbe', 'ModProbe'), ('PiPico', 'PiPico'),
-           ('VEML7700', 'VEML7700'))
+           ('VEML7700', 'VEML7700'),('PMSA0031','PMSA0031'))
 
 
 class HardwareTypeForm(forms.Form):
