@@ -18,6 +18,8 @@ from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
     CalibrationSerializer, HubSerializer, HardwareIOSerializer
 
+from OpenHubAPI.data.forms.forms import HardwarePMSA0031Form
+
 SPI = 'SPI'
 Serial = 'Serial'
 PWM = 'PWM'
@@ -50,7 +52,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 form = HardwarePiPicoForm(data=request.POST, instance=hardware)
             if hardware_type == 'VEML7700':
                 form = HardwareVEML7700Form(data=request.POST, instance=hardware)
-
+            if hardware_type == 'PMSA0031':
+                form = HardwarePMSA0031Form(data=request.POST, instance=hardware)
             # save the data and after fetch the object in instance
             if form.is_valid():
                 instance = form.save()
@@ -74,6 +77,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
             form = HardwarePiPicoForm(initial={'type': 'PiPico'})
         if hardware_type == 'VEML7700':
             form = HardwareVEML7700Form(initial={'type': 'VEML7700'})
+        if hardware_type == 'PMSA0031':
+            form = HardwarePMSA0031Form(initial={'type': 'PMSA0031'})
         return HttpResponse(form.as_p())
 
     def getHardwareIoForm(request):
@@ -222,6 +227,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 hardware_form = HardwarePiPicoForm(request.POST)
             if hardware_type == 'VEML7700':
                 hardware_form = HardwareVEML7700Form(request.POST)
+            if hardware_type == 'PMSA0031':
+                form = HardwarePMSA0031Form(request.POST)
 
             # save the data and after fetch the object in instance
             if hardware_form.is_valid():
@@ -271,6 +278,9 @@ class HardwareViewSet(viewsets.ModelViewSet):
             if hardware_type == 'VEML7700':
                 hardware_form = HardwareVEML7700Form(instance=VEML7700.objects.get(**kwargs),
                                                      initial={'type': 'VEML7700'})
+            if hardware_type == 'PMSA0031':
+                hardware_form = HardwarePMSA0031Form(instance=PMSA0031.objects.get(**kwargs),
+                                                     initial={'type': 'PMSA0031'})
         except:
             hardware_form = HardwareForm(instance=Hardware.objects.get(**kwargs))
 
